import { __decorate } from "tslib/tslib.es6.js";
/**
@license
Copyright 2018 Google Inc. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import { matches } from "../dom/ponyfill.js";
import { addHasRemoveClass, BaseElement } from "../mwc-base/base-element.js";
import MDCTabScrollerFoundation from "../tab-scroller/foundation.js";
import { eventOptions, html, query } from "./node_modules/lit-element/lit-element.js";
export class TabScrollerBase extends BaseElement {
  constructor() {
    super(...arguments);
    this.mdcFoundationClass = MDCTabScrollerFoundation;
    this._scrollbarHeight = -1;
  }

  _handleInteraction() {
    this.mdcFoundation.handleInteraction();
  }

  _handleTransitionEnd(e) {
    this.mdcFoundation.handleTransitionEnd(e);
  }

  render() {
    return html`
      <div class="mdc-tab-scroller">
        <div class="mdc-tab-scroller__scroll-area"
            @wheel="${this._handleInteraction}"
            @touchstart="${this._handleInteraction}"
            @pointerdown="${this._handleInteraction}"
            @mousedown="${this._handleInteraction}"
            @keydown="${this._handleInteraction}"
            @transitionend="${this._handleTransitionEnd}">
          <div class="mdc-tab-scroller__scroll-content"><slot></slot></div>
        </div>
      </div>
      `;
  }

  createAdapter() {
    return Object.assign(Object.assign({}, addHasRemoveClass(this.mdcRoot)), {
      eventTargetMatchesSelector: (evtTarget, selector) => matches(evtTarget, selector),
      addScrollAreaClass: className => this.scrollAreaElement.classList.add(className),
      setScrollAreaStyleProperty: (prop, value) => this.scrollAreaElement.style.setProperty(prop, value),
      setScrollContentStyleProperty: (prop, value) => this.scrollContentElement.style.setProperty(prop, value),
      getScrollContentStyleValue: propName => window.getComputedStyle(this.scrollContentElement).getPropertyValue(propName),
      setScrollAreaScrollLeft: scrollX => this.scrollAreaElement.scrollLeft = scrollX,
      getScrollAreaScrollLeft: () => this.scrollAreaElement.scrollLeft,
      getScrollContentOffsetWidth: () => this.scrollContentElement.offsetWidth,
      getScrollAreaOffsetWidth: () => this.scrollAreaElement.offsetWidth,
      computeScrollAreaClientRect: () => this.scrollAreaElement.getBoundingClientRect(),
      computeScrollContentClientRect: () => this.scrollContentElement.getBoundingClientRect(),
      computeHorizontalScrollbarHeight: () => {
        if (this._scrollbarHeight === -1) {
          this.scrollAreaElement.style.overflowX = 'scroll';
          this._scrollbarHeight = this.scrollAreaElement.offsetHeight - this.scrollAreaElement.clientHeight;
          this.scrollAreaElement.style.overflowX = '';
        }

        return this._scrollbarHeight;
      }
    });
  }
  /**
   * Returns the current visual scroll position
   * @return {number}
   */


  getScrollPosition() {
    return this.mdcFoundation.getScrollPosition();
  }
  /**
   * Returns the width of the scroll content
   * @return {number}
   */


  getScrollContentWidth() {
    return this.scrollContentElement.offsetWidth;
  }
  /**
   * Increments the scroll value by the given amount
   * @param {number} scrollXIncrement The pixel value by which to increment the
   *     scroll value
   */


  incrementScrollPosition(scrollXIncrement) {
    this.mdcFoundation.incrementScroll(scrollXIncrement);
  }
  /**
   * Scrolls to the given pixel position
   * @param {number} scrollX The pixel value to scroll to
   */


  scrollToPosition(scrollX) {
    this.mdcFoundation.scrollTo(scrollX);
  }

}

__decorate([query('.mdc-tab-scroller')], TabScrollerBase.prototype, "mdcRoot", void 0);

__decorate([query('.mdc-tab-scroller__scroll-area')], TabScrollerBase.prototype, "scrollAreaElement", void 0);

__decorate([query('.mdc-tab-scroller__scroll-content')], TabScrollerBase.prototype, "scrollContentElement", void 0);

__decorate([eventOptions({
  passive: true
})], TabScrollerBase.prototype, "_handleInteraction", null);